


nav[data-toggle="toc"] {
	top: 32px;
}

/* small screens */
@media (max-width: 768px) {
	/* override stickyness so that the navigation does not follow scrolling */
	nav[data-toggle="toc"] {
	  margin-bottom: 32px;
	  position: static;
	}

	/* PICK ONE */
	/* don't expand nested items, which pushes down the rest of the page when navigating */
	nav[data-toggle="toc"] .nav .active .nav {
	  display: none;
	}
	/* alternatively, if you *do* want the second-level navigation to be shown (as seen on this page on mobile), use this */
	/*
	nav[data-toggle='toc'] .nav .nav {
	  display: block;
	}
	*/
}

h1 {
	padding: 12px 0px;
	margin-bottom: 6px;
	border-bottom: 1px solid #004080;
	font-size: 2.2rem;
}

h2 {
	font-size: 1.8rem;
	margin: 30px 0px 12px 0px;
}

h2[text=Reference] {
	font-size: 1.1rem
}

h3 {
	font-size: 1.4rem;
	margin-top: .8rem;
}

h4 {
	font-size: 1rem;
	margin-top: .8rem;
	margin-bottom: .5rem;
}

div.card div.card-header h3,
div.card div.card-header h4,
div.card div.card-header h5 {
	margin-top: 0px;
}

div.nav-tabs a.nav-item h3,
div.nav-tabs a.nav-item h4,
div.nav-tabs a.nav-item h5,
div.card div.card-header h3 button,
div.card div.card-header h4 button,
div.card div.card-header h5 button {
	margin: 2px 4px;
	font-size: .9rem;
	font-weight: bold
}

div.card-header {
	padding: .25rem
}

.page-footer{
	font-size: .8rem
}

div.tab div.tab {
	margin: 4px;
	background-color: #FFF;
}

.dataTables_filter label {
	margin-bottom: 0px;
}

.dataTables_wrapper label,
.dataTables_wrapper li.paginate_button,
.dataTables_wrapper div.dataTables_info,
.dataTables_wrapper .dataTables_filter input,
.dataTables_wrapper .dataTables_length select {
	font-size: .75rem;
}
.dataTables_wrapper > div.row {
	overflow-x: auto;
}
.table.dataTable {
	margin-top: 0px !important
}
figcaption {
	font-size:.9rem;
	padding-top: .3rem;
}
div.tabwrap {
	margin-top:1rem !important;
}
div.tablewrapper {
	margin-top:1.5rem !important;
	margin-bottom:1.5rem !important;
    padding: 1.5rem .75rem;
	background-color: #dad7ff21;
	font-size:.75rem;
}

.btn-group-sm>.btn, .btn-sm {
	font-size:.75rem;
}

.bd-navbar {
	position: -webkit-sticky;
	position: sticky;
	top: 0;
	z-index: 1071;
	min-height: 4rem;
	background-color: #563d7c;
	box-shadow: 0 0.5rem 1rem rgba(0,0,0,.05), inset 0 -1px 0 rgba(0,0,0,.1);
}
.ml-md-auto, .mx-md-auto {
	margin-left: auto!important;
}
#toc-controller {color: #e3e3e3;}

#pyppl-report-title {
	color: white;
	font-size: 20px;
}

.nav-pills .nav-link.active, .nav-pills .show>.nav-link {
    color: #fff;
    background-color: #007bff;
}

#pyppl-report-toc{
	width: 300px;
	display: inline-block;
}

.bd-toc {
	position: sticky;
	top: 64px;
	height: calc(100vh - 64px);
	overflow-y: auto;
}

.navbar-brand{
	white-space: normal;
}

.nav-1 {
	font-weight: bold;
	font-size: 18px;
}

.nav-2 {
	font-size: 16px;
	margin-left: 10px;
}

.nav-3 {
	font-size: 14px;
	margin-left: 20px;
}

.nav-4 {
	font-size: 12px;
	margin-left: 30px;
}

.nav-5 {
	font-size: 10px;
	margin-left: 40px;
}

#pyppl-report-toc .nav-link {
	padding: 4px 16px;
}


code {
    padding: .2em .4em;
    margin: 0;
    font-size: 85%;
    background-color: rgba(27,31,35,.05);
    border-radius: 3px;
    white-space: pre-wrap;
}

pre > code.sourceCode { white-space: pre; position: relative; background: transparent; }
pre > code.sourceCode > span { display: inline-block; line-height: 1.25; margin-left: -72px;}
pre > code.sourceCode > span:first-child { margin-left: 0}
pre > code.sourceCode > span:empty { height: 1.2em; }
code.sourceCode > span { color: inherit; text-decoration: inherit; }
div.sourceCode { margin: 1em 0; }
pre.sourceCode { margin: 0; background-color:rgba(27,31,35,.05); padding: 8px 4px; }
@media screen {
div.sourceCode { overflow: auto; }
}
@media print {
pre > code.sourceCode { white-space: pre-wrap; }
pre > code.sourceCode > span { text-indent: -5em; padding-left: 5em; }
}
pre.numberSource code
  { counter-reset: source-line 0; }
pre.numberSource code > span
  { position: relative; left: -4em; counter-increment: source-line; }
pre.numberSource code > span > a:first-child::before
  { content: counter(source-line);
    position: relative; left: -1em; text-align: right; vertical-align: baseline;
    border: none; display: inline-block;
    -webkit-touch-callout: none; -webkit-user-select: none;
    -khtml-user-select: none; -moz-user-select: none;
    -ms-user-select: none; user-select: none;
    padding: 0 4px; width: 4em;
    color: #aaaaaa;
  }
pre.numberSource { margin-left: 3em; border-left: 1px solid #aaaaaa;  padding-left: 4px; }
div.sourceCode
  {   }
@media screen {
pre > code.sourceCode > span > a:first-child::before { text-decoration: underline; }
}
code span.al { color: #ff0000; font-weight: bold; } /* Alert */
code span.an { color: #60a0b0; font-weight: bold; font-style: italic; } /* Annotation */
code span.at { color: #7d9029; } /* Attribute */
code span.bn { color: #40a070; } /* BaseN */
code span.bu { } /* BuiltIn */
code span.cf { color: #007020; font-weight: bold; } /* ControlFlow */
code span.ch { color: #4070a0; } /* Char */
code span.cn { color: #880000; } /* Constant */
code span.co { color: #60a0b0; font-style: italic; } /* Comment */
code span.cv { color: #60a0b0; font-weight: bold; font-style: italic; } /* CommentVar */
code span.do { color: #ba2121; font-style: italic; } /* Documentation */
code span.dt { color: #902000; } /* DataType */
code span.dv { color: #40a070; } /* DecVal */
code span.er { color: #ff0000; font-weight: bold; } /* Error */
code span.ex { } /* Extension */
code span.fl { color: #40a070; } /* Float */
code span.fu { color: #06287e; } /* Function */
code span.im { } /* Import */
code span.in { color: #60a0b0; font-weight: bold; font-style: italic; } /* Information */
code span.kw { color: #007020; font-weight: bold; } /* Keyword */
code span.op { color: #666666; } /* Operator */
code span.ot { color: #007020; } /* Other */
code span.pp { color: #bc7a00; } /* Preprocessor */
code span.sc { color: #4070a0; } /* SpecialChar */
code span.ss { color: #bb6688; } /* SpecialString */
code span.st { color: #4070a0; } /* String */
code span.va { color: #19177c; } /* Variable */
code span.vs { color: #4070a0; } /* VerbatimString */
code span.wa { color: #60a0b0; font-weight: bold; font-style: italic; } /* Warning */

p {
	margin-bottom: 8px;
}

.admon-title {
	font-weight: bold;
	font-size: 18px;
}

.alert {
	padding-bottom: 4px;
}


table caption {
	caption-side: top;
	padding-top: 0rem !important;
	padding-bottom: .5rem;
	font-size: .9rem;
}


.dataTables_filter label {
	margin-bottom: 0px;
}

.dataTables_wrapper label,
.dataTables_wrapper li.paginate_button,
.dataTables_wrapper div.dataTables_info,
.dataTables_wrapper .dataTables_filter input,
.dataTables_wrapper .dataTables_length select {
	font-size: .75rem;
}
.dataTables_wrapper > div.row {
	overflow-x: auto;
}
.table.dataTable {
	margin-top: 0px !important
}

div.dataTables_wrapper {
	margin-top:1.5rem !important;
	margin-bottom:1.5rem !important;
    padding: 1.5rem .75rem;
	background-color: #dad7ff21;
	font-size:.75rem;
}



figure {
	background-color: #dad7ff21;
}

figure img {
    margin: 15px;
    cursor: zoom-in;
}

figure > figcaption {
    padding: 0px 15px 15px 15px;
}

figure .img-tag {
    vertical-align: top;
    display: inline-block;
    margin: 15px 15px 15px -15px;
    background: white;
    padding: 8px;
}

.tab-content {
	padding: 12px 16px;
    border-bottom: 1px solid #dee2e6;
    border-left: 1px solid #dee2e6;
    border-right: 1px solid #dee2e6;
}

.modal-content{
	top: 28px;
}

.pyppl-report-reference {
    display: block;
}
