

.with-toc {
    margin-left: 150px;
}

.without-toc {
    margin-left: -150px;
}

#pyppl-report-footer {
    text-align: right;
    font-style: italic;
    font-size: 11px;
    padding: 15px;
}

a {
    color: #01AAED;
}

a[download="true"] {
    color: rgb(237, 1, 217);
}

.layui-table {width: 100% !important;}

.layui-table td {
    line-height: 13px;
    font-size: 13px;
}

.layui-table th {
    line-height: 15px;
    font-size: 13px;
    font-weight: bold;
}

.layui-table-cell {
    line-height: 1;
    height: auto;
}

.layui-nav-side {
    top: 60px;
    width: 300px;
    background-color: #f1f1f1;
}

.layui-col-md1 {
    text-align: center;
}

#pyppl-report-header {
    background-color: rgb(27, 120, 160);
    display: block;
    z-index: 1000;
    height: 60px;

    border-bottom: none;
}

#pyppl-report-main {
    top: 60px;
    padding: 15px 45px 30px 0px;
}

#pyppl-report-title {
    padding: 10px 24px;
    font-size: 24px;
    line-height: 36px;
    color: rgb(255, 255, 255);
}

#toc-controller {
    /* font-size: 20px; */
    /* line-height: 60px; */
    color: white;
    /* border-color: white; */
    border: 1px solid #331c1c;
    padding: 5px;
    cursor: pointer;
    position: absolute;
    background-color: white;
    left: 20px;
    bottom: 30px;
    z-index: 2099;
}

figure {
    margin: 0;
    border: 1px solid #e6e6e6;
    background-color: #f6f6f6;
}

figure img {
    margin: 15px;
    cursor: zoom-in;
}

figure > figcaption {
    padding: 0px 15px 15px 15px;
}

figure .img-tag {
    vertical-align: top;
    display: inline-block;
    margin: 15px 15px 15px -15px;
    background: white;
    padding: 8px;
}

.pyppl-report-refindex {
    vertical-align: super;
    font-size: 11px;
}

code {
    padding: .2em .4em;
    margin: 0;
    font-size: 85%;
    background-color: rgba(27,31,35,.05);
    border-radius: 3px;
    white-space: pre-wrap;
}

pre > code.sourceCode { white-space: pre; position: relative; background: transparent; }
pre > code.sourceCode > span { display: inline-block; line-height: 1.25; margin-left: -36px;}
pre > code.sourceCode > span:first-child { margin-left: 0}
pre > code.sourceCode > span:empty { height: 1.2em; }
code.sourceCode > span { color: inherit; text-decoration: inherit; }
div.sourceCode { margin: 1em 0; }
pre.sourceCode { margin: 0; background-color:rgba(27,31,35,.05); padding: 8px 4px; }
@media screen {
div.sourceCode { overflow: auto; }
}
@media print {
pre > code.sourceCode { white-space: pre-wrap; }
pre > code.sourceCode > span { text-indent: -5em; padding-left: 5em; }
}
pre.numberSource code
  { counter-reset: source-line 0; }
pre.numberSource code > span
  { position: relative; left: -4em; counter-increment: source-line; }
pre.numberSource code > span > a:first-child::before
  { content: counter(source-line);
    position: relative; left: -1em; text-align: right; vertical-align: baseline;
    border: none; display: inline-block;
    -webkit-touch-callout: none; -webkit-user-select: none;
    -khtml-user-select: none; -moz-user-select: none;
    -ms-user-select: none; user-select: none;
    padding: 0 4px; width: 4em;
    color: #aaaaaa;
  }
pre.numberSource { margin-left: 3em; border-left: 1px solid #aaaaaa;  padding-left: 4px; }
div.sourceCode
  {   }
@media screen {
pre > code.sourceCode > span > a:first-child::before { text-decoration: underline; }
}
code span.al { color: #ff0000; font-weight: bold; } /* Alert */
code span.an { color: #60a0b0; font-weight: bold; font-style: italic; } /* Annotation */
code span.at { color: #7d9029; } /* Attribute */
code span.bn { color: #40a070; } /* BaseN */
code span.bu { } /* BuiltIn */
code span.cf { color: #007020; font-weight: bold; } /* ControlFlow */
code span.ch { color: #4070a0; } /* Char */
code span.cn { color: #880000; } /* Constant */
code span.co { color: #60a0b0; font-style: italic; } /* Comment */
code span.cv { color: #60a0b0; font-weight: bold; font-style: italic; } /* CommentVar */
code span.do { color: #ba2121; font-style: italic; } /* Documentation */
code span.dt { color: #902000; } /* DataType */
code span.dv { color: #40a070; } /* DecVal */
code span.er { color: #ff0000; font-weight: bold; } /* Error */
code span.ex { } /* Extension */
code span.fl { color: #40a070; } /* Float */
code span.fu { color: #06287e; } /* Function */
code span.im { } /* Import */
code span.in { color: #60a0b0; font-weight: bold; font-style: italic; } /* Information */
code span.kw { color: #007020; font-weight: bold; } /* Keyword */
code span.op { color: #666666; } /* Operator */
code span.ot { color: #007020; } /* Other */
code span.pp { color: #bc7a00; } /* Preprocessor */
code span.sc { color: #4070a0; } /* SpecialChar */
code span.ss { color: #bb6688; } /* SpecialString */
code span.st { color: #4070a0; } /* String */
code span.va { color: #19177c; } /* Variable */
code span.vs { color: #4070a0; } /* VerbatimString */
code span.wa { color: #60a0b0; font-weight: bold; font-style: italic; } /* Warning */

h1 {
    margin: 24px 0px 12px 0px;
}

h2 {
    margin: 18px 0px 8px 0px;
}

h1 + h2 {
    margin-top: 0px;
}

h2 {
    margin: 18px 0px 8px 0px;
}

h3 {
    font-weight: bold;
    margin: 10px 0px 6px 0px;
}

h2 + h3 {
    margin-top: 0px;
}

p {line-height: 20px; margin: 8px 0;}

/** admonition */
.admon {
    position: relative;
    margin: 14px 0;
    padding: 0 10px;
    border-color:rgba(68, 137, 255, 0.192);
    border-width: 1px 1px 1px 2px;
    border-style: solid;
    border-left-color: #448aff;
    overflow: auto;
}

.admon p {
    margin: 12px 0px;
}

.admon i {
    color: #448aff;
    margin-right: 8px;
}

.admon-title {
    margin: 0 -10px !important;
    padding: 5px 10px;
    border-bottom: 1px solid rgba(68,138,255,.1);
    background-color: rgba(68,138,255,.1);
    font-weight: bold;
}

.admon.warning, .admon.warn {
    border-color: rgba(255, 145, 0, 0.199);
    border-left-color: #ff9100;
}

.admon.warning .admon-title, .admon.warn .admon-title {
    background-color: rgba(255,145,0,.1);
}

.admon.warning i, .admon.warn i {
    color: #ff9100;
}

.admon.info, .admon.tip {
    border-color: rgba(0, 184, 212, 0.219);
    border-left-color: #00b8d4;
}

.admon.info .admon-title, .admon.tip .admon-title {
    background-color: rgba(0,184,212,.1);
}

.admon.info i, .admon.tip i {
    color: #00b8d4
}

.admon.error, .admon.danger {
    border-color: rgba(255,23,68,.2);
    border-left-color: #ff1744;
}

.admon.error .admon-title, .admon.danger .admon-title {
    background-color: rgba(255,23,68,.1);
}

.admon.error i, .admon.danger i {
    color: #ff1744
}

.admon.example {
    border-color: rgba(101,31,255,.2);
    border-left-color: #651fff;
}

.admon.example .admon-title {
    background-color: rgba(101,31,255,.1);
}

.admon.example i {
    color: #651fff;
}


.layui-nav-tree a {
    color: rgb(46, 46, 46) !important;
}

.layui-nav-tree>.layui-this>a {
    border-left: 5px solid #009688;
    font-weight: bold;
}

.layui-nav-tree .layui-nav-item a:hover {
    background-color: #dad7ff21;
    color: black !important;
}
.layui-nav-tree .layui-nav-item dd dd>a {
    font-size: 12px;
    padding: 6px 4px 2px 0px;
    margin-left: -10px;
}

.layui-nav-tree .layui-this, .layui-nav-tree .layui-this>a, .layui-nav-tree .layui-this>a:hover, .layui-nav-tree .layui-nav-child dd.layui-this, .layui-nav-tree .layui-nav-child dd.layui-this a {
    background-color: inherit;
}

.layui-nav-tree .layui-nav-itemed>.layui-nav-child {
    background-color: #fff !important;
    padding-bottom: 5px;
}

.layui-nav-tree .layui-nav-child a{
    display: block;
    white-space: normal;
    line-height: 18px;
    height: auto;
    padding: 10px 4px 5px 0px;
}

.layui-nav-tree .layui-nav-child dd {
    padding-left: 24px;
}

.layui-nav-tree .layui-nav-child a:hover,
.layui-nav-tree .layui-this .layui-nav-child .layui-this a{
    color: #009688 !important;
}

.layui-nav .layui-nav-mored, .layui-nav-itemed > a .layui-nav-more {
    border-bottom-color: #666;
}

.layui-nav .layui-nav-more {
    border-top-color: #666;
}

.pyppl-report-reference {
    display: block;
}


ul:not([class]), ol {
    margin-left: 20px;
}

ul:not([class]) > li:last-child, ol > li:last-child {
    margin-bottom: 6px;
}

ol > li {
    list-style-type: inherit;
}

ul > li > p {
    display: inline-block;
}

.layui-border-box {
    margin-bottom: 18px;
}
ul > li {
    list-style-position: outside;
    list-style-type: square;
    margin-top: 2px;
}
