.ui.left.rail {
	left: 0px;
	height: auto;
}

#pyppl-report-main {
	padding: 30px;
	border-left: 1px solid rgba(34,36,38,.15);
}

#pyppl-report-main.with-toc {
	margin-left: 300px;
}

#pyppl-report-main.without-toc {
	margin-left: 0px;
}

#pyppl-report-toc {
	padding: 25px;
	width: 300px;
}

#pyppl-report-container {
	margin: 0px !important;
	width: 100%;
}


code {
    padding: .2em .4em;
    margin: 0;
    font-size: 85%;
    background-color: rgba(27,31,35,.05);
    border-radius: 3px;
    white-space: pre-wrap;
}

pre > code.sourceCode { white-space: pre; position: relative; background: transparent; }
pre > code.sourceCode > span { display: inline-block; line-height: 1.25; margin-left: -36px;}
pre > code.sourceCode > span:first-child { margin-left: 0}
pre > code.sourceCode > span:empty { height: 1.2em; }
code.sourceCode > span { color: inherit; text-decoration: inherit; }
div.sourceCode { margin: 1em 0; }
pre.sourceCode { margin: 0; background-color:rgba(27,31,35,.05); padding: 8px 4px; }
@media screen {
div.sourceCode { overflow: auto; }
}
@media print {
pre > code.sourceCode { white-space: pre-wrap; }
pre > code.sourceCode > span { text-indent: -5em; padding-left: 5em; }
}
pre.numberSource code
  { counter-reset: source-line 0; }
pre.numberSource code > span
  { position: relative; left: -4em; counter-increment: source-line; }
pre.numberSource code > span > a:first-child::before
  { content: counter(source-line);
    position: relative; left: -1em; text-align: right; vertical-align: baseline;
    border: none; display: inline-block;
    -webkit-touch-callout: none; -webkit-user-select: none;
    -khtml-user-select: none; -moz-user-select: none;
    -ms-user-select: none; user-select: none;
    padding: 0 4px; width: 4em;
    color: #aaaaaa;
  }
pre.numberSource { margin-left: 3em; border-left: 1px solid #aaaaaa;  padding-left: 4px; }
div.sourceCode
  {   }
@media screen {
pre > code.sourceCode > span > a:first-child::before { text-decoration: underline; }
}
code span.al { color: #ff0000; font-weight: bold; } /* Alert */
code span.an { color: #60a0b0; font-weight: bold; font-style: italic; } /* Annotation */
code span.at { color: #7d9029; } /* Attribute */
code span.bn { color: #40a070; } /* BaseN */
code span.bu { } /* BuiltIn */
code span.cf { color: #007020; font-weight: bold; } /* ControlFlow */
code span.ch { color: #4070a0; } /* Char */
code span.cn { color: #880000; } /* Constant */
code span.co { color: #60a0b0; font-style: italic; } /* Comment */
code span.cv { color: #60a0b0; font-weight: bold; font-style: italic; } /* CommentVar */
code span.do { color: #ba2121; font-style: italic; } /* Documentation */
code span.dt { color: #902000; } /* DataType */
code span.dv { color: #40a070; } /* DecVal */
code span.er { color: #ff0000; font-weight: bold; } /* Error */
code span.ex { } /* Extension */
code span.fl { color: #40a070; } /* Float */
code span.fu { color: #06287e; } /* Function */
code span.im { } /* Import */
code span.in { color: #60a0b0; font-weight: bold; font-style: italic; } /* Information */
code span.kw { color: #007020; font-weight: bold; } /* Keyword */
code span.op { color: #666666; } /* Operator */
code span.ot { color: #007020; } /* Other */
code span.pp { color: #bc7a00; } /* Preprocessor */
code span.sc { color: #4070a0; } /* SpecialChar */
code span.ss { color: #bb6688; } /* SpecialString */
code span.st { color: #4070a0; } /* String */
code span.va { color: #19177c; } /* Variable */
code span.vs { color: #4070a0; } /* VerbatimString */
code span.wa { color: #60a0b0; font-weight: bold; font-style: italic; } /* Warning */

.ui.button.btn {
	font-size: 12px !important;
    padding: 7px 12px;
}

.dataTables_filter.ui.form .form-control-sm {
	width: 200px;
    padding: 0;
    height: 26px;
    margin-left: 4px;
}

table caption {
	caption-side: top;
	padding-top: 14px !important;
	padding-bottom: 8px;
	text-align: left;
}


.dataTables_filter label {
	margin-bottom: 0px;
}

.dataTables_wrapper label,
.dataTables_wrapper li.paginate_button,
.dataTables_wrapper div.dataTables_info,
.dataTables_wrapper .dataTables_filter input,
.dataTables_wrapper > div.row {
	overflow-x: auto;
}
.dataTables_wrapper > div.row > div.col-4 {
	display: inline-block;
	width: 33%;
}
.dataTables_wrapper > div.row > div.col-6 {
	width: 50%;
	float: left;
}
.table.dataTable {
	margin-top: 0px !important
}

.dataTables_wrapper .text-right {
	text-align: right;
}

.dataTables_wrapper li.paginate_button {
	display: inline;
}
.dataTables_wrapper li.paginate_button a {
	padding: 2px 6px;
	cursor: pointer;
}
.dataTables_wrapper li.paginate_button.disabled a {
	color: #ccc;
}
.dataTables_wrapper li.paginate_button.active a {
	background-color: rgb(51, 105, 255);
	color: white;
}
div.dataTables_wrapper div.dataTables_info {
	padding-top: 0;
}
.dataTables_wrapper {
	margin-top:1.5rem !important;
	margin-bottom:1.5rem !important;
    padding: 1.5rem .75rem;
	background-color: #dad7ff21;
}

a[download] {
	color: #903bf1;
}

figure {
    margin: 0;
    border: 1px solid #e6e6e6;
    background-color: #f6f6f6;
}

figure img {
    margin: 15px;
    cursor: zoom-in;
}

figure > figcaption {
    padding: 0px 15px 15px 15px;
}

figure .img-tag {
    vertical-align: top;
    display: inline-block;
    margin: 15px 15px 15px -15px;
    background: white;
    padding: 8px;
}

.pyppl-report-refindex {
    vertical-align: super;
    font-size: 11px;
}

.footer {
	text-align: right;
    font-size: 11px !important;
    font-style: italic;
}

.ui.text.menu .active.item {
	font-weight: bold !important;
}

.ui.text.menu a.item {
	padding-left: 10px !important;
}

.pagetitle {
	font-size: 36px;
    font-weight: bold;
    padding: 10px 0px;
}

#toc-controller{
    position: fixed;
    left: 20px;
    bottom: 30px;
    z-index: 2000;
}

#toc-controller i.icon {
	font-size: 32px;
	cursor: pointer;
	background-color: white;
}

.pyppl-report-reference {
    display: block;
}
