<!doctype html>
<html lang="en">
<head>
  <script data-pace-options='{"ajax": false}' src="static/pace.min.js"></script>
  <link rel="stylesheet" type="text/css" href="static/pace.css" />
  <meta name="viewport" content="width=device-width, initial-scale=1.0" />

  <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
  <meta http-equiv="Content-Style-Type" content="text/css" />
  <link rel="stylesheet" type="text/css" href="static/css/layui.css" />
  <link rel="stylesheet" type="text/css" href="static/css/modules/laydate/default/laydate.css" />
  <link rel="stylesheet" type="text/css" href="static/css/modules/layer/default/layer.css" />
  <link rel="stylesheet" type="text/css" href="static/css/modules/code.css" />
  <link rel="stylesheet" type="text/css" href="static/template.css" />
  <meta name="generator" content="pandoc" />

  <title>$pagetitle$</title>
$if(pdf)$
  <style type="text/css">
    thead { display: table-header-group; }
    tfoot { display: table-row-group; }
    tr { page-break-inside: avoid; }
  </style>
$endif$
</head>

<body>
$if(toc)$
<a class="layui-icon-left layui-icon layui-circle layui-bg-black"
    id="toc-controller"
    title="Toggle sidebar"
    href="javascript:void(0);"></a>
$endif$
<div class="layui-header layui-row" id="pyppl-report-header">
  <div id="pyppl-report-title" class="layui-col-md12">$pagetitle$</div>
</div>
<div class="layui-body" id="pyppl-report-main">

    <div class="layui-row">
      $body$
    </div>

    <div class="layui-footer layui-row" id="pyppl-report-footer">
      <div>
        $if(pdf)$ Powered $else$ Best experience with
        <a href="https://www.google.com/chrome/">Chrome</a>,
        powered
        $endif$
        by <a href="https://github.com/pwwang/PyPPL">PyPPL</a>
        v$pyppl_version$ with
        <a href="https://github.com/pwwang/pyppl-report">
          pyppl-report
        </a> v$report_version$
      </div>
    </div>
</div>
<script type="text/javascript">
  window.metadata = {};
  window.metadata.toc = $if(toc)$ $toc$ $else$ 0 $endif$;
  window.metadata.pdf = $if(pdf)$ true $else$ false $endif$;
</script>
<script src="static/jquery.min.js"></script>
<script src="static/adapter.js"></script>
$if(pdf)$
$else$
<script src="static/layui.all.js"></script>
<script src="static/template.js"></script>
$endif$
</body>
</html>
