<!doctype html>
<html lang="en">
<head>
  <meta name="viewport" content="width=device-width, initial-scale=1.0" />

  <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
  <meta http-equiv="Content-Style-Type" content="text/css" />
  <link rel="stylesheet" type="text/css" href="static/datatables.min.css" />
  <link rel="stylesheet" type="text/css" href="static/semantic.min.css" />
  <link rel="stylesheet" type="text/css" href="static/template.css" />
  <meta name="generator" content="pandoc" />

  <title>$pagetitle$</title>
$if(pdf)$
  <style type="text/css">
    thead { display: table-header-group; }
    tfoot { display: table-row-group; }
    tr { page-break-inside: avoid; }
  </style>
$endif$
</head>

<body class="menu pushable">
<div class="pusher">
  <div class="full height main ui container" id="pyppl-report-container">
    <div class="article" id="pyppl-report-main">
      <div class="pagetitle">$pagetitle$</div>
      $body$

      <div class="ui  vertical footer segment">
        <div class="text-sm-right font-weight-lighter font-italic py-1">
          $if(pdf)$ Powered $else$ Best experience with
          <a href="https://www.google.com/chrome/">Chrome</a>,
          powered
          $endif$
          by <a href="https://github.com/pwwang/PyPPL">PyPPL</a>
          v$pyppl_version$ with
          <a href="https://github.com/pwwang/pyppl-report">
            pyppl-report
          </a> v$report_version$
        </div>
      </div>
    </div>

  </div>
</div>
<script type="text/javascript">
  window.metadata = {};
  window.metadata.toc = $if(toc)$ $toc$ $else$ 0 $endif$;
  window.metadata.pdf = $if(pdf)$ true $else$ false $endif$;
</script>
<script src="static/jquery.min.js"></script>
<script src="static/adapter.js"></script>
$if(pdf)$
$else$
<script src="static/semantic.min.js"></script>
<script src="static/datatables.min.js"></script>
<script src="static/echo.min.js"></script>
<script src="static/template.js"></script>
$endif$
</body data-spy="scroll">
</html>
